from setuptools import setup

setup(name='distributions-Lavinia',
      version='0.1',
      description='Gaussian and binomial distributions',
      packages=['distributions-Lavinia'],
      author='Lavinia Calinoiu',
      zip_safe=False)
